/*
 * @Author: zc
 * @description 辅助功能-号码信息配置
 */
import request from '@/utils/request';
/**
 * @description 获取号码信息列表基础信息
 * @param {object} params
 */
export const getNumberInfoBaseData = (params?: object) => {
	return request({
		url: '/api/v1/SystemMobilArea/get-base-data',
		method: 'get',
		params,
	});
};
/**
 * @description 获取号码信息列表
 * @param {object} params
 */
export const getNumberInfoList = (params?: object) => {
	return request({
		url: '/api/v1/SystemMobilArea/get-system-mobil-area-list',
		method: 'get',
		params,
	});
};

/**
 * @description 号码信息列表 导出
 * @param {object} data
 */
export const exportNumberInfo = (data?: object) => {
	return request(
		{
			url: '/api/v1/SystemMobilArea/get-system-mobil-area-list-export',
			method: 'post',
			data,
			responseType: 'blob',
		},
		{
			reduce_data_format: false,
		}
	);
};
/**
 * @description 号码信息
 * @param {object} data
 */
export const addNumberInfo = (data: object) => {
	return request({
		url: '/api/v1/SystemMobilArea/add-system-mobil-area',
		method: 'post',
		data,
	});
};
/**
 * @description 号码信息详情
 * @param {string} id
 * @return {*}
 * */
export const getNumberInfoDetail = (id: string) => {
	return request({
		url: `/api/v1/SystemMobilArea/get-system-mobil-area-detail/${id}`,
		method: 'get',
	});
};
/**
 * @description 号码信息编辑
 * @param {object} data
 */
export const updateNumberInfo = (data: object) => {
	return request({
		url: '/api/v1/SystemMobilArea/update-system-mobil-area',
		method: 'put',
		data,
	});
};
/**
 * @description 号码信息删除
 * @param {string} id
 * @return {*}
 * */
export const deleteNumberInfo = (id: string) => {
	return request({
		url: `/api/v1/SystemMobilArea/delete-system-mobil-area-detail/${id}`,
		method: 'delete',
	});
};
